from __future__ import print_function
from make_colors import make_colors
linenumbers = "[10]"
PID = "1029304"
linenumbers = " " + make_colors(str(linenumbers), 'red', 'on_white') + "] " + make_colors("PID:", 'red', 'lightgreen') + make_colors(str(PID), 'lightwhite')
print("linenumbers =", linenumbers)



from debug import *
import sys
import traceback

def function_test(param1, param2, param3):
	debug(print_function_parameters=True)

function_test("test_parameter_1", "test_parameter_2", "test_parameter_3")

